@@ -17,80 +17,73 @@
 #ifndef GLOBUS_GSI_SYSTEM_CONFIG_H
 #define GLOBUS_GSI_SYSTEM_CONFIG_H
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * @file globus_gsi_system_config.h
+ * @brief Globus GSI System Config Library
  * @author Sam Lang, Sam Meder
- *
- * $RCSfile: globus_gsi_system_config.h,v $
- * $Revision: 1.18.48.1 $
- * $Date: 2012/02/13 14:46:31 $
  */
-#endif
-
-#ifndef EXTERN_C_BEGIN
-#    ifdef __cplusplus
-#        define EXTERN_C_BEGIN extern "C" {
-#        define EXTERN_C_END }
-#    else
-#        define EXTERN_C_BEGIN
-#        define EXTERN_C_END
-#    endif
-#endif
-
-EXTERN_C_BEGIN
 
 #include "globus_common.h"
 #include "globus_gsi_system_config_constants.h"
 #include "openssl/x509.h"
 
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#ifndef GLOBUS_GLOBAL_DOCUMENT_SET
 /**
  * @mainpage Globus GSI System Config API
  *
+ * @copydoc globus_gsi_sysconfig
+ */
+#endif
+
+/**
+ * @defgroup globus_gsi_sysconfig Globus GSI System Config API
+ *
  * This API provides helper functions for detecting installation and
- * environment specific settings applicabale to GSI. It also servers as a
- * abstraction layer for OS specific programming details. This is achieves by
- * defining preprocessor symbols that point at the correct platform specific
- * function. <b>You should never use the platform specific functions
- * directly.</b>.
+ * environment specific settings applicable to GSI. It also servers as a
+ * abstraction layer for OS specific programming details. The public interface
+ * for this library consists of the GLOBUS_GSI_SYSCONFIG_* macros that point at
+ * the resolve to platform specific functions. <b>You should never use the
+ * platform specific functions directly.</b>.
+ *
  * Any program that uses Globus GSI System Config functions must include
- * "globus_gsi_system_config.h".  
+ * the globus_gsi_system_config.h header.
  *
- * @htmlonly
- * <a href="main.html" target="_top">View documentation without frames</a><br>
- * <a href="index.html" target="_top">View documentation with frames</a><br>
- * @endhtmlonly
  */
 
 /**
  * @defgroup globus_gsi_system_config_defines Defines
+ * @ingroup globus_gsi_sysconfig
  *
- * These precompiler defines allow for a platform (ie Win32 vs UNIX)
+ * These preprocessor defines allow for a platform (ie Win32 vs UNIX)
  * independent API.
- *
  */
 
-
 /**
  * @defgroup globus_gsi_sysconfig_unix Functions for UNIX platforms
+ * @ingroup globus_gsi_sysconfig
  *
  * These functions implement the UNIX version of the Globus GSI System
  * Configuration API. <b>They should never be called directly, please use the
  * provided platform independent defines.</b>
- *
  */
 
 /**
  * @defgroup globus_gsi_sysconfig_win32 Functions for Win32 platforms 
+ * @ingroup globus_gsi_sysconfig
  *
  * These functions implement the Win32 version of the Globus GSI System
  * Configuration API. <b>They should never be called directly, please use the
  * provided platform independent defines.</b>
- *
  */
 
 /**
  * @defgroup globus_gsi_sysconfig_shared Functions for all platforms
+ * @ingroup globus_gsi_sysconfig
  *
  * These functions are platform independent members of the Globus GSI System
  * Configuration API. 
@@ -108,18 +101,17 @@ EXTERN_C_BEGIN
 /**
  * @defgroup globus_i_gsi_system_config_win32 Internal Globus Credential
  * System Config API for Win32 platforms
- *
  */
 
 /**
  * @defgroup globus_i_gsi_system_config_unix Internal Globus Credential
  * System Config API for Unix platforms
- *
  */
 #endif
 
 /** 
  * @defgroup globus_gsi_sysconfig_activation Activation
+ * @ingroup globus_gsi_sysconfig
  *
  * Globus GSI System Configuration API uses standard Globus module activation
  * and deactivation.  Before any Globus GSI System Configuration API functions
@@ -145,7 +137,6 @@ EXTERN_C_BEGIN
  *
  * This function should be called once for each time Globus GSI System
  * Configuration API was activated. 
- *
  */
 
 /** Module descriptor
@@ -157,10 +148,6 @@ EXTERN_C_BEGIN
 extern 
 globus_module_descriptor_t              globus_i_gsi_sysconfig_module;
 
-#define _GSSL(s) globus_common_i18n_get_string(\
-			GLOBUS_GSI_SYSCONFIG_MODULE,\
-			s)
-
 #ifdef WIN32
 #    define GLOBUS_GSI_SYSCONFIG_SET_KEY_PERMISSIONS \
             globus_gsi_sysconfig_set_key_permissions_win32
@@ -659,6 +646,8 @@ globus_result_t
 globus_gsi_sysconfig_get_unique_proxy_filename(
     char **                             unique_filename);
 
-EXTERN_C_END
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* GLOBUS_GSI_SYSTEM_CONFIG_H */
